==> AgeOn1.8.1_source.zip: AgeOn1.8.1_source/nispi/Controls/Menu/MainMenu/ThreadViewMenu/BrowserTextMainMenu.cs <==
//CZXAgeOntH_LISENCEtH_QƂĂ
using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Forms;
using System.Drawing;
using System.Diagnostics;
using mshtml;

using nispi.controlclass;

namespace nispi.Menu
{
    class BrowserTextMainMenu
    {
        /*IꂽeLXgꍇ*/
        public ToolStripMenuItemParts menuItemOpenGoogleParts;
        public ToolStripMenuItemParts menuItemOpenWikiParts;
        public ToolStripMenuItemParts menuItemCopyParts;
        public ToolStripMenuItemParts menuItemSamplingParts;

        public TextMenuEvent textMenuEvent;

        public BrowserTextMainMenu(ToolStripMenuItemParts menuItem)
        {
            menuItemOpenGoogleParts = ToolStripMenuItemPartsManager.Pop();
            menuItemOpenWikiParts = ToolStripMenuItemPartsManager.Pop();
            menuItemCopyParts = ToolStripMenuItemPartsManager.Pop();
            menuItemSamplingParts = ToolStripMenuItemPartsManager.Pop();

            //IꂽeLXgꍇ
            menuItemOpenGoogleParts.Text = '\"' + "" + '\"' + "GoogleŌ";
            menuItemOpenWikiParts.Text = '\"' + "" + '\"' + "WikiŊJ";
            menuItemCopyParts.Text = "Rs[";
            menuItemSamplingParts.Text = '\"' + "" + '\"' + "𒊏o\";

            menuItem.DropDownItemsAdd(menuItemOpenGoogleParts);
            menuItem.DropDownItemsAdd(menuItemOpenWikiParts);
            menuItem.DropDownItemsAdd("-");
            menuItem.DropDownItemsAdd(menuItemCopyParts);
            menuItem.DropDownItemsAdd("-");
            menuItem.DropDownItemsAdd(menuItemSamplingParts);

            textMenuEvent = new TextMenuEvent(this);
        }

        public void SetMainMenu()
        {
            int index = Const.form.threadListTabControlParts.SelectedIndex;
            ThreadViewCommon threadView = MainFormConst.threadListTabMain.viewList[index];
            string text = "";

            HtmlUtil.GetSelectText(ref text, threadView.threadViewControls.browserParts);
            //IꂽeLXgꍇ
            if ((text != null) && (text.Length > 0))
            {
                //IꂽeLXgꍇ
                menuItemOpenGoogleParts.Text = '\"' + text + '\"' + "GoogleŌ";
                menuItemOpenWikiParts.Text = '\"' + text + '\"' + "WikiŊJ";
                menuItemCopyParts.Text = "Rs[";
                menuItemSamplingParts.Text = '\"' + text + '\"' + "𒊏o\";

                menuItemOpenGoogleParts.Enabled = true;
                menuItemOpenWikiParts.Enabled = true;
                menuItemCopyParts.Enabled = true;
                menuItemSamplingParts.Enabled = true;

                textMenuEvent.selectedText = text;
                
            }
            else
            {
                //IꂽeLXgȂꍇi͎sȂj
                menuItemOpenGoogleParts.Text = "\"" + "\"" + "GoogleŌ";
                menuItemOpenWikiParts.Text = "\"" + "\"" + "WikiŊJ";
                menuItemCopyParts.Text = "Rs[";
                menuItemSamplingParts.Text = '\"' + text + '\"' + "𒊏o\";

                menuItemOpenGoogleParts.Enabled = false;
                menuItemOpenWikiParts.Enabled = false;
                menuItemCopyParts.Enabled = false;
                menuItemSamplingParts.Enabled = false;
            }
        }
    }
}

==> AgeOn1.8.2_source.zip: AgeOn1.8.2_source/nispi/Controls/Menu/MainMenu/ThreadViewMenu/BrowserTextMainMenu.cs <==
//CZXAgeOntH_LISENCEtH_QƂĂ
using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Forms;
using System.Drawing;
using System.Diagnostics;
using mshtml;

using nispi.controlclass;

namespace nispi.Menu
{
    class BrowserTextMainMenu
    {
        /*IꂽeLXgꍇ*/
        public ToolStripMenuItemParts menuItemOpenGoogleParts;
        public ToolStripMenuItemParts menuItemOpenWikiParts;
        public ToolStripMenuItemParts menuItemCopyParts;
        public ToolStripMenuItemParts menuItemSamplingParts;

        public TextMenuEvent textMenuEvent;

        public BrowserTextMainMenu(ToolStripMenuItemParts menuItem)
        {
            menuItemOpenGoogleParts = ToolStripMenuItemPartsManager.Pop();
            menuItemOpenWikiParts = ToolStripMenuItemPartsManager.Pop();
            menuItemCopyParts = ToolStripMenuItemPartsManager.Pop();
            menuItemSamplingParts = ToolStripMenuItemPartsManager.Pop();

            //IꂽeLXgꍇ
            menuItemOpenGoogleParts.Text = '\"' + "" + '\"' + "GoogleŌ(&G)";
            menuItemOpenWikiParts.Text = '\"' + "" + '\"' + "WikiŊJ(&W)";
            menuItemCopyParts.Text = "Rs[(&C)";
            menuItemSamplingParts.Text = '\"' + "" + '\"' + "𒊏o\(&T)";

            menuItem.DropDownItemsAdd(menuItemOpenGoogleParts);
            menuItem.DropDownItemsAdd(menuItemOpenWikiParts);
            menuItem.DropDownItemsAdd("-");
            menuItem.DropDownItemsAdd(menuItemCopyParts);
            menuItem.DropDownItemsAdd("-");
            menuItem.DropDownItemsAdd(menuItemSamplingParts);

            textMenuEvent = new TextMenuEvent(this);
        }

        public void SetMainMenu()
        {
            int index = Const.form.threadListTabControlParts.SelectedIndex;
            ThreadViewCommon threadView = MainFormConst.threadListTabMain.viewList[index];
            string text = "";

            HtmlUtil.GetSelectText(ref text, threadView.threadViewControls.browserParts);
            //IꂽeLXgꍇ
            if ((text != null) && (text.Length > 0))
            {
                //IꂽeLXgꍇ
                menuItemOpenGoogleParts.Text = '\"' + text + '\"' + "GoogleŌ(&G)";
                menuItemOpenWikiParts.Text = '\"' + text + '\"' + "WikiŊJ(&W)";
                menuItemCopyParts.Text = "Rs[(&C)";
                menuItemSamplingParts.Text = '\"' + text + '\"' + "𒊏o\(&T)";

                menuItemOpenGoogleParts.Enabled = true;
                menuItemOpenWikiParts.Enabled = true;
                menuItemCopyParts.Enabled = true;
                menuItemSamplingParts.Enabled = true;

                textMenuEvent.selectedText = text;
                
            }
            else
            {
                //IꂽeLXgȂꍇi͎sȂj
                menuItemOpenGoogleParts.Text = "\"" + "\"" + "GoogleŌ(&G)";
                menuItemOpenWikiParts.Text = "\"" + "\"" + "WikiŊJ(&W)";
                menuItemCopyParts.Text = "Rs[(&C)";
                menuItemSamplingParts.Text = '\"' + text + '\"' + "𒊏o\(&T)";

                menuItemOpenGoogleParts.Enabled = false;
                menuItemOpenWikiParts.Enabled = false;
                menuItemCopyParts.Enabled = false;
                menuItemSamplingParts.Enabled = false;
            }
        }
    }
}
